aboutsummaryrefslogtreecommitdiff
path: root/actions
diff options
context:
space:
mode:
authorcash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-11-19 20:43:48 +0000
committercash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-11-19 20:43:48 +0000
commit3b46665b3f4ee10e9d2778033ea7180cca7571eb (patch)
tree6cbea6da55887db7bbd587df9b7e4d8cb209cea2 /actions
parentf42382e0bff1692e2ddcd1c8eb316836e3020f1e (diff)
downloadelgg-3b46665b3f4ee10e9d2778033ea7180cca7571eb.tar.gz
elgg-3b46665b3f4ee10e9d2778033ea7180cca7571eb.tar.bz2
saving widget settings
git-svn-id: http://code.elgg.org/elgg/trunk@7350 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'actions')
-rw-r--r--actions/widgets/save.php20
1 files changed, 4 insertions, 16 deletions
diff --git a/actions/widgets/save.php b/actions/widgets/save.php
index 945634d97..4af60c7de 100644
--- a/actions/widgets/save.php
+++ b/actions/widgets/save.php
@@ -1,29 +1,17 @@
<?php
/**
* Elgg widget save action
*
* @package Elgg.Core
* @subpackage Widgets.Management
*/
$guid = get_input('guid');
-$params = $_REQUEST['params'];
-$pageurl = get_input('pageurl');
-$noforward = get_input('noforward', false);
+$params = get_input('params');
-$result = false;
+$result = elgg_save_widget_settings($guid, $params);
-if (!empty($guid)) {
- $result = save_widget_info($guid, $params);
-}
-
-if ($noforward) {
- exit;
-}
-
-if ($result) {
- system_message(elgg_echo('widgets:save:success'));
-} else {
+if (!$result) {
register_error(elgg_echo('widgets:save:failure'));
}
@@ -1,29 +1,17 @@
<?php
/**
- * Elgg widget save action
+ * Elgg save widget settings action
*
* @package Elgg.Core